News for IRCO 0.6.1 — IRCO 0.7.1 documentation

# News for IRCO 0.6.1

## Upgrade

You can install the latest version of the irco tool by issuing the following command:

    pip install --upgrade irco

At the time of writing the latest version is 0.6.1. This is a minor release which introduces some user interface related changes, as better described below.

## Explorer update

Version 0.6.1 is a small update to the explorer which adds styling and pagination in order to provide a faster and overall more enjoyable user experience.

For more information about the IRCO Explorer, see IRCO Explorer.

## Next steps

The next version will provide additional utilities to work on data, such as institution geolocation and entries deduplication (merging of institution or author records refering to the same entity).